============================
So You Want to Contribute...
============================
For general information on contributing to OpenStack, please check out the
`contributor guide <https://docs.openstack.org/contributors/>`_ to get started.
It covers all the basics that are common to all OpenStack projects: the accounts
you need, the basics of interacting with our Gerrit review system, how we
communicate as a community, etc.
Below will cover the more project specific information you need to get started
with heat-dashboard.

Communication
~~~~~~~~~~~~~
* IRC channel #heat at OFTC
* Mailing list (prefix subjects with ``[heat]`` for faster responses)
  http://lists.openstack.org/cgi-bin/mailman/listinfo/openstack-discuss

Contacting the Core Team
~~~~~~~~~~~~~~~~~~~~~~~~
Please refer the `heat-dashboard Core Team
<https://review.opendev.org/admin/groups/8803fcad46b4bce76ed436861474878f36e0a8e4,members>`_ contacts.

New Feature Planning
~~~~~~~~~~~~~~~~~~~~
heat-dashboard features are tracked on `Storyboard <https://storyboard.openstack.org/#!/project/openstack/heat-dashboard>`_.

Task Tracking
~~~~~~~~~~~~~
We track our tasks in `Storyboard <https://storyboard.openstack.org/#!/project/openstack/heat-dashboard>`_.
If you're looking for some smaller, easier work item to pick up and get started
on, search for the 'low-hanging-fruit' tag.

Reporting a Bug
~~~~~~~~~~~~~~~
You found an issue and want to make sure we are aware of it? You can do so on
`Storyboard <https://storyboard.openstack.org/#!/project/openstack/heat-dashboard>`_.

Getting Your Patch Merged
~~~~~~~~~~~~~~~~~~~~~~~~~
All changes proposed to the heat-dashboard project require one or two +2 votes
from heat-dashboard core reviewers before one of the core reviewers can approve
patch by giving ``Workflow +1`` vote.

Project Team Lead Duties
~~~~~~~~~~~~~~~~~~~~~~~~
All common PTL duties are enumerated in the `PTL guide
<https://docs.openstack.org/project-team-guide/ptl.html>`_.
